# Changelog

## 0.3.1

* Add `SurveyScenario` class
* Add OpenFisca-Survey-Manager optional dependancy

## 0.3.1

* Clarify setup.cfg

## 0.3.0

* Add parameters.xml in MANIFEST.in

## 0.0.0

* Unreleased
